=== modified file 'bzrlib/cache_utf8.py'
--- bzrlib/cache_utf8.py	2007-02-09 16:41:00 +0000
+++ bzrlib/cache_utf8.py	2007-02-10 02:48:43 +0000
@@ -61,7 +61,8 @@
     try:
         return _utf8_to_uni[utf8_str]
     except KeyError:
-        _utf8_to_uni[utf8_str] = unicode_str = _utf8_decode(utf8_str)[0]
+        unicode_str = _utf8_decode(utf8_str)[0]
+        _utf8_to_uni[utf8_str] = unicode_str
         _uni_to_utf8[unicode_str] = utf8_str
         return unicode_str
 

=== modified file 'bzrlib/knit.py'
--- bzrlib/knit.py	2007-02-08 21:52:53 +0000
+++ bzrlib/knit.py	2007-02-10 02:48:43 +0000
@@ -73,6 +73,7 @@
 from bzrlib import (
     cache_utf8,
     errors,
+    osutils,
     patiencediff,
     progress,
     ui,
@@ -156,9 +157,9 @@
 class _KnitFactory(object):
     """Base factory for creating content objects."""
 
-    def make(self, lines, version):
+    def make(self, lines, version_id):
         num_lines = len(lines)
-        return KnitContent(zip([version] * num_lines, lines))
+        return KnitContent(zip([version_id] * num_lines, lines))
 
 
 class KnitAnnotateFactory(_KnitFactory):
@@ -166,7 +167,7 @@
 
     annotated = True
 
-    def parse_fulltext(self, content, version):
+    def parse_fulltext(self, content, version_id):
         """Convert fulltext to internal representation
 
         fulltext content is of the format
@@ -174,13 +175,17 @@
         internal representation is of the format:
         (revid, plaintext)
         """
-        lines = [line.split(' ', 1) for line in content]
+        # TODO: jam 20070209 The tests expect this to be returned as tuples,
+        #       but the code itself doesn't really depend on that.
+        #       Figure out a way to not require the overhead of turning the
+        #       list back into tuples.
+        lines = [tuple(line.split(' ', 1)) for line in content]
         return KnitContent(lines)
 
     def parse_line_delta_iter(self, lines):
         return iter(self.parse_line_delta(lines))
 
-    def parse_line_delta(self, lines, version):
+    def parse_line_delta(self, lines, version_id):
         """Convert a line based delta into internal representation.
 
         line delta is in the form of:
@@ -197,7 +202,7 @@
         # walk through the lines parsing.
         for header in lines:
             start, end, count = [int(n) for n in header.split(',')]
-            contents = [next().split(' ', 1) for i in xrange(count)]
+            contents = [tuple(next().split(' ', 1)) for i in xrange(count)]
             result.append((start, end, count, contents))
         return result
 
@@ -225,19 +230,23 @@
 
         see parse_fulltext which this inverts.
         """
-        encode_utf8 = cache_utf8.encode
-        return ['%s %s' % (encode_utf8(o), t) for o, t in content._lines]
+        # TODO: jam 20070209 We only do the caching thing to make sure that
+        #       the origin is a valid utf-8 line, eventually we could remove it
+        get_cached_utf8 = cache_utf8.get_cached_utf8
+        return ['%s %s' % (get_cached_utf8(o), t) for o, t in content._lines]
 
     def lower_line_delta(self, delta):
         """convert a delta into a serializable form.
 
         See parse_line_delta which this inverts.
         """
-        encode_utf8 = cache_utf8.encode
+        # TODO: jam 20070209 We only do the caching thing to make sure that
+        #       the origin is a valid utf-8 line, eventually we could remove it
+        get_cached_utf8 = cache_utf8.get_cached_utf8
         out = []
         for start, end, c, lines in delta:
             out.append('%d,%d,%d\n' % (start, end, c))
-            out.extend(encode_utf8(origin) + ' ' + text
+            out.extend(get_cached_utf8(origin) + ' ' + text
                        for origin, text in lines)
         return out
 
@@ -247,26 +256,26 @@
 
     annotated = False
 
-    def parse_fulltext(self, content, version):
+    def parse_fulltext(self, content, version_id):
         """This parses an unannotated fulltext.
 
         Note that this is not a noop - the internal representation
         has (versionid, line) - its just a constant versionid.
         """
-        return self.make(content, version)
+        return self.make(content, version_id)
 
-    def parse_line_delta_iter(self, lines, version):
+    def parse_line_delta_iter(self, lines, version_id):
         cur = 0
         num_lines = len(lines)
         while cur < num_lines:
             header = lines[cur]
             cur += 1
             start, end, c = [int(n) for n in header.split(',')]
-            yield start, end, c, zip([version] * c, lines[cur:cur+c])
+            yield start, end, c, zip([version_id] * c, lines[cur:cur+c])
             cur += c
 
-    def parse_line_delta(self, lines, version):
-        return list(self.parse_line_delta_iter(lines, version))
+    def parse_line_delta(self, lines, version_id):
+        return list(self.parse_line_delta_iter(lines, version_id))
 
     def get_fulltext_content(self, lines):
         """Extract just the content lines from a fulltext."""
@@ -491,7 +500,7 @@
         return KnitVersionedFile(name, transport, factory=self.factory,
                                  delta=self.delta, create=True)
     
-    def _fix_parents(self, version, new_parents):
+    def _fix_parents(self, version_id, new_parents):
         """Fix the parents list for version.
         
         This is done by appending a new version to the index
@@ -499,9 +508,9 @@
         the parents list must be a superset of the current
         list.
         """
-        current_values = self._index._cache[version]
+        current_values = self._index._cache[version_id]
         assert set(current_values[4]).difference(set(new_parents)) == set()
-        self._index.add_version(version,
+        self._index.add_version(version_id,
                                 current_values[1], 
                                 current_values[2],
                                 current_values[3],
@@ -509,6 +518,7 @@
 
     def get_delta(self, version_id):
         """Get a delta for constructing version from some other version."""
+        version_id = osutils.safe_revision_id(version_id)
         self.check_not_reserved_id(version_id)
         if not self.has_version(version_id):
             raise RevisionNotPresent(version_id, self.filename)
@@ -520,10 +530,9 @@
             parent = None
         data_pos, data_size = self._index.get_position(version_id)
         data, sha1 = self._data.read_records(((version_id, data_pos, data_size),))[version_id]
-        version_idx = self._index.lookup(version_id)
         noeol = 'no-eol' in self._index.get_options(version_id)
         if 'fulltext' == self._index.get_method(version_id):
-            new_content = self.factory.parse_fulltext(data, version_idx)
+            new_content = self.factory.parse_fulltext(data, version_id)
             if parent is not None:
                 reference_content = self._get_content(parent)
                 old_texts = reference_content.text()
@@ -533,7 +542,7 @@
             delta_seq = KnitSequenceMatcher(None, old_texts, new_texts)
             return parent, sha1, noeol, self._make_line_delta(delta_seq, new_content)
         else:
-            delta = self.factory.parse_line_delta(data, version_idx)
+            delta = self.factory.parse_line_delta(data, version_id)
             return parent, sha1, noeol, delta
         
     def get_graph_with_ghosts(self):
@@ -543,6 +552,7 @@
 
     def get_sha1(self, version_id):
         """See VersionedFile.get_sha1()."""
+        version_id = osutils.safe_revision_id(version_id)
         record_map = self._get_record_map([version_id])
         method, content, digest, next = record_map[version_id]
         return digest 
@@ -554,6 +564,7 @@
 
     def has_ghost(self, version_id):
         """True if there is a ghost reference in the file to version_id."""
+        version_id = osutils.safe_revision_id(version_id)
         # maybe we have it
         if self.has_version(version_id):
             return False
@@ -572,6 +583,7 @@
 
     def has_version(self, version_id):
         """See VersionedFile.has_version."""
+        version_id = osutils.safe_revision_id(version_id)
         return self._index.has_version(version_id)
 
     __contains__ = has_version
@@ -790,6 +802,7 @@
 
     def get_line_list(self, version_ids):
         """Return the texts of listed versions as a list of strings."""
+        version_ids = [osutils.safe_revision_id(v) for v in version_ids]
         for version_id in version_ids:
             self.check_not_reserved_id(version_id)
         text_map, content_map = self._get_content_maps(version_ids)
@@ -825,12 +838,11 @@
                 if component_id in content_map:
                     content = content_map[component_id]
                 else:
-                    version_idx = self._index.lookup(component_id)
                     if method == 'fulltext':
                         assert content is None
-                        content = self.factory.parse_fulltext(data, version_idx)
+                        content = self.factory.parse_fulltext(data, version_id)
                     elif method == 'line-delta':
-                        delta = self.factory.parse_line_delta(data, version_idx)
+                        delta = self.factory.parse_line_delta(data, version_id)
                         content = content.copy()
                         content._lines = self._apply_delta(content._lines, 
                                                            delta)
@@ -856,6 +868,8 @@
         """See VersionedFile.iter_lines_added_or_present_in_versions()."""
         if version_ids is None:
             version_ids = self.versions()
+        else:
+            version_ids = [osutils.safe_revision_id(v) for v in version_ids]
         if pb is None:
             pb = progress.DummyProgress()
         # we don't care about inclusions, the caller cares.
@@ -878,7 +892,6 @@
             enumerate(self._data.read_records_iter(version_id_records)):
             pb.update('Walking content.', version_idx, total)
             method = self._index.get_method(version_id)
-            version_idx = self._index.lookup(version_id)
 
             assert method in ('fulltext', 'line-delta')
             if method == 'fulltext':
@@ -898,6 +911,7 @@
 
     def annotate_iter(self, version_id):
         """See VersionedFile.annotate_iter."""
+        version_id = osutils.safe_revision_id(version_id)
         content = self._get_content(version_id)
         for origin, text in content.annotate_iter():
             yield origin, text
@@ -907,6 +921,7 @@
         # perf notes:
         # optimism counts!
         # 52554 calls in 1264 872 internal down from 3674
+        version_id = osutils.safe_revision_id(version_id)
         try:
             return self._index.get_parents(version_id)
         except KeyError:
@@ -914,6 +929,7 @@
 
     def get_parents_with_ghosts(self, version_id):
         """See VersionedFile.get_parents."""
+        version_id = osutils.safe_revision_id(version_id)
         try:
             return self._index.get_parents_with_ghosts(version_id)
         except KeyError:
@@ -925,6 +941,7 @@
             versions = [versions]
         if not versions:
             return []
+        versions = [osutils.safe_revision_id(v) for v in versions]
         return self._index.get_ancestry(versions)
 
     def get_ancestry_with_ghosts(self, versions):
@@ -933,6 +950,7 @@
             versions = [versions]
         if not versions:
             return []
+        versions = [osutils.safe_revision_id(v) for v in versions]
         return self._index.get_ancestry_with_ghosts(versions)
 
     #@deprecated_method(zero_eight)
@@ -958,6 +976,8 @@
 
     def plan_merge(self, ver_a, ver_b):
         """See VersionedFile.plan_merge."""
+        ver_a = osutils.safe_revision_id(ver_a)
+        ver_b = osutils.safe_revision_id(ver_b)
         ancestors_b = set(self.get_ancestry(ver_b))
         def status_a(revision, text):
             if revision in ancestors_b:
@@ -1121,7 +1141,6 @@
         # so - wc -l of a knit index is != the number of unique names
         # in the knit.
         self._history = []
-        decode_utf8 = cache_utf8.decode
         pb = ui.ui_factory.nested_progress_bar()
         try:
             pb.update('read knit index', 0, 1)
@@ -1148,6 +1167,7 @@
     def _load_data(self, fp):
         cache = self._cache
         history = self._history
+        get_cached_utf8 = cache_utf8.get_cached_utf8
 
         self.check_header(fp)
         # readlines reads the whole file at once:
@@ -1172,11 +1192,13 @@
             for value in rec[4:-1]:
                 if value[0] == '.':
                     # uncompressed reference
-                    parents.append(value[1:])
+                    parent_id = get_cached_utf8(value[1:])
                 else:
-                    parents.append(history[int(value)])
+                    parent_id = history[int(value)]
+                parents.append(parent_id)
 
             version_id, options, pos, size = rec[:4]
+            version_id = get_cached_utf8(version_id)
 
             # See self._cache_version
             # only want the _history index to reference the 1st 
@@ -1252,7 +1274,11 @@
         return self._cache[version_id][5]
 
     def _version_list_to_index(self, versions):
-        encode_utf8 = cache_utf8.encode
+        # TODO: jam 20070209 We only do the caching thing to make sure that
+        #       what we have in memory is already a proper utf-8 string
+        #       Eventually we should be able to write out the index without
+        #       doing any sort of encode step
+        get_cached_utf8 = cache_utf8.get_cached_utf8
         result_list = []
         cache = self._cache
         for version in versions:
@@ -1261,7 +1287,7 @@
                 result_list.append(str(cache[version][5]))
                 # -- end lookup () --
             else:
-                result_list.append('.' + encode_utf8(version))
+                result_list.append('.' + get_cached_utf8(version))
         return ' '.join(result_list)
 
     def add_version(self, version_id, options, pos, size, parents):
@@ -1275,13 +1301,16 @@
                          (version_id, options, pos, size, parents).
         """
         lines = []
-        encode_utf8 = cache_utf8.encode
+        # TODO: jam 20070209 get_cached_utf8 is just used to verify the
+        #       version_ids are indeed utf-8 eventually these calls can be
+        #       removed
+        get_cached_utf8 = cache_utf8.get_cached_utf8
         orig_history = self._history[:]
         orig_cache = self._cache.copy()
 
         try:
             for version_id, options, pos, size, parents in versions:
-                line = "\n%s %s %s %s %s :" % (encode_utf8(version_id),
+                line = "\n%s %s %s %s %s :" % (get_cached_utf8(version_id),
                                                ','.join(options),
                                                pos,
                                                size,
@@ -1395,7 +1424,7 @@
         sio = StringIO()
         data_file = GzipFile(None, mode='wb', fileobj=sio)
 
-        version_id_utf8 = cache_utf8.encode(version_id)
+        version_id_utf8 = cache_utf8.get_cached_utf8(version_id)
         data_file.writelines(chain(
             ["version %s %d %s\n" % (version_id_utf8,
                                      len(lines),
@@ -1457,7 +1486,7 @@
         if len(rec) != 4:
             raise KnitCorrupt(self._filename,
                               'unexpected number of elements in record header')
-        if cache_utf8.decode(rec[1]) != version_id:
+        if rec[1] != version_id:
             raise KnitCorrupt(self._filename,
                               'unexpected version, wanted %r, got %r'
                               % (version_id, rec[1]))

=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2007-01-24 11:20:17 +0000
+++ bzrlib/repository.py	2007-02-10 02:48:43 +0000
@@ -90,39 +90,41 @@
         )
 
     @needs_write_lock
-    def add_inventory(self, revid, inv, parents):
-        """Add the inventory inv to the repository as revid.
+    def add_inventory(self, revision_id, inv, parents):
+        """Add the inventory inv to the repository as revision_id.
         
-        :param parents: The revision ids of the parents that revid
+        :param parents: The revision ids of the parents that revision_id
                         is known to have and are in the repository already.
 
         returns the sha1 of the serialized inventory.
         """
-        _mod_revision.check_not_reserved_id(revid)
-        assert inv.revision_id is None or inv.revision_id == revid, \
+        revision_id = osutils.safe_revision_id(revision_id)
+        _mod_revision.check_not_reserved_id(revision_id)
+        assert inv.revision_id is None or inv.revision_id == revision_id, \
             "Mismatch between inventory revision" \
-            " id and insertion revid (%r, %r)" % (inv.revision_id, revid)
+            " id and insertion revid (%r, %r)" % (inv.revision_id, revision_id)
         assert inv.root is not None
         inv_text = self.serialise_inventory(inv)
         inv_sha1 = osutils.sha_string(inv_text)
         inv_vf = self.control_weaves.get_weave('inventory',
                                                self.get_transaction())
-        self._inventory_add_lines(inv_vf, revid, parents, osutils.split_lines(inv_text))
+        self._inventory_add_lines(inv_vf, revision_id, parents,
+                                  osutils.split_lines(inv_text))
         return inv_sha1
 
-    def _inventory_add_lines(self, inv_vf, revid, parents, lines):
+    def _inventory_add_lines(self, inv_vf, revision_id, parents, lines):
         final_parents = []
         for parent in parents:
             if parent in inv_vf:
                 final_parents.append(parent)
 
-        inv_vf.add_lines(revid, final_parents, lines)
+        inv_vf.add_lines(revision_id, final_parents, lines)
 
     @needs_write_lock
-    def add_revision(self, rev_id, rev, inv=None, config=None):
-        """Add rev to the revision store as rev_id.
+    def add_revision(self, revision_id, rev, inv=None, config=None):
+        """Add rev to the revision store as revision_id.
 
-        :param rev_id: the revision id to use.
+        :param revision_id: the revision id to use.
         :param rev: The revision object.
         :param inv: The inventory for the revision. if None, it will be looked
                     up in the inventory storer
@@ -130,20 +132,21 @@
                        If supplied its signature_needed method will be used
                        to determine if a signature should be made.
         """
-        _mod_revision.check_not_reserved_id(rev_id)
+        revision_id = osutils.safe_revision_id(revision_id)
+        _mod_revision.check_not_reserved_id(revision_id)
         if config is not None and config.signature_needed():
             if inv is None:
-                inv = self.get_inventory(rev_id)
+                inv = self.get_inventory(revision_id)
             plaintext = Testament(rev, inv).as_short_text()
             self.store_revision_signature(
-                gpg.GPGStrategy(config), plaintext, rev_id)
-        if not rev_id in self.get_inventory_weave():
+                gpg.GPGStrategy(config), plaintext, revision_id)
+        if not revision_id in self.get_inventory_weave():
             if inv is None:
-                raise errors.WeaveRevisionNotPresent(rev_id,
+                raise errors.WeaveRevisionNotPresent(revision_id,
                                                      self.get_inventory_weave())
             else:
                 # yes, this is not suitable for adding with ghosts.
-                self.add_inventory(rev_id, inv, rev.parent_ids)
+                self.add_inventory(revision_id, inv, rev.parent_ids)
         self._revision_store.add_revision(rev, self.get_transaction())
 
     @needs_read_lock
@@ -292,6 +295,7 @@
         :param revprops: Optional dictionary of revision properties.
         :param revision_id: Optional revision id.
         """
+        revision_id = osutils.safe_revision_id(revision_id)
         return _CommitBuilder(self, parents, config, timestamp, timezone,
                               committer, revprops, revision_id)
 
@@ -777,6 +781,11 @@
                     revision_id.encode('ascii')
                 except UnicodeEncodeError:
                     raise errors.NonAsciiRevisionId(method, self)
+            else:
+                try:
+                    revision_id.decode('ascii')
+                except UnicodeDecodeError:
+                    raise errors.NonAsciiRevisionId(method, self)
 
 
 class AllInOneRepository(Repository):

=== modified file 'bzrlib/store/revision/__init__.py'
--- bzrlib/store/revision/__init__.py	2006-11-10 21:06:11 +0000
+++ bzrlib/store/revision/__init__.py	2007-02-10 02:48:43 +0000
@@ -28,12 +28,11 @@
 from copy import deepcopy
 import unittest
 
-import bzrlib
 from bzrlib import (
     errors,
+    osutils,
     xml5,
     )
-import bzrlib.store
 """)
 
 from bzrlib.trace import mutter
@@ -127,6 +126,7 @@
         
         :return: a signature text.
         """
+        revision_id = osutils.safe_revision_id(revision_id)
         self._guard_revision(revision_id, transaction)
         return self._get_signature_text(revision_id, transaction)
 
@@ -145,6 +145,7 @@
 
     def has_signature(self, revision_id, transaction):
         """True if the store has a signature for revision_id."""
+        revision_id = osutils.safe_revision_id(revision_id)
         self._guard_revision(revision_id, transaction)
         return self._has_signature(revision_id, transaction)
 

=== modified file 'bzrlib/store/revision/knit.py'
--- bzrlib/store/revision/knit.py	2006-12-12 15:26:42 +0000
+++ bzrlib/store/revision/knit.py	2007-02-10 02:48:43 +0000
@@ -21,7 +21,6 @@
 """
 
 
-import bzrlib
 from bzrlib import errors, osutils
 from bzrlib.knit import KnitVersionedFile, KnitPlainFactory
 from bzrlib.store.revision import RevisionStore
@@ -70,6 +69,7 @@
 
     def add_revision_signature_text(self, revision_id, signature_text, transaction):
         """See RevisionStore.add_revision_signature_text()."""
+        revision_id = osutils.safe_revision_id(revision_id)
         self.get_signature_file(transaction).add_lines(
             revision_id, [], osutils.split_lines(signature_text))
 
@@ -80,6 +80,7 @@
 
     def get_revisions(self, revision_ids, transaction):
         """See RevisionStore.get_revisions()."""
+        revision_ids = [osutils.safe_revision_id(r) for r in revision_ids]
         texts = self._get_serialized_revisions(revision_ids, transaction)
         revisions = []
         try:
@@ -90,7 +91,7 @@
         except SyntaxError, e:
             raise errors.BzrError('failed to unpack revision_xml for %s: %s' %
                                    (revision_id, str(e)))
-        return revisions 
+        return revisions
 
     def _get_serialized_revisions(self, revision_ids, transaction):
         texts = []
@@ -123,9 +124,10 @@
 
     def has_revision_id(self, revision_id, transaction):
         """True if the store contains revision_id."""
+        revision_id = osutils.safe_revision_id(revision_id)
         return (revision_id is None
                 or self.get_revision_file(transaction).has_version(revision_id))
-        
+
     def _has_signature(self, revision_id, transaction):
         """See RevisionStore._has_signature()."""
         return self.get_signature_file(transaction).has_version(revision_id)

=== modified file 'bzrlib/store/revision/text.py'
--- bzrlib/store/revision/text.py	2006-11-10 21:06:11 +0000
+++ bzrlib/store/revision/text.py	2007-02-10 02:48:43 +0000
@@ -24,8 +24,11 @@
 from cStringIO import StringIO
 
 
-import bzrlib
-import bzrlib.errors as errors
+from bzrlib import (
+    cache_utf8,
+    errors,
+    osutils,
+    )
 from bzrlib.store.revision import RevisionStore
 from bzrlib.store.text import TextStore
 from bzrlib.store.versioned import VersionedFileStore
@@ -64,11 +67,16 @@
 
     def _add_revision(self, revision, revision_as_file, transaction):
         """Template method helper to store revision in this store."""
-        self.text_store.add(revision_as_file, revision.revision_id)
+        # TODO: jam 20070209 text_store.add() still requires a unicode file id
+        unicode_revision_id = cache_utf8.decode(revision.revision_id)
+        self.text_store.add(revision_as_file, unicode_revision_id)
 
     def add_revision_signature_text(self, revision_id, signature_text, transaction):
         """See RevisionStore.add_revision_signature_text()."""
-        self.text_store.add(StringIO(signature_text), revision_id, "sig")
+        # TODO: jam 20070209 text_store.add() still requires a unicode file id
+        revision_id_unicode = cache_utf8.decode(revision_id)
+        self.text_store.add(StringIO(signature_text), revision_id_unicode,
+                            "sig")
 
     def all_revision_ids(self, transaction):
         """See RevisionStore.all_revision_ids()."""
@@ -77,6 +85,7 @@
         assert self.text_store.listable()
         result_graph = {}
         for rev_id in self.text_store:
+            rev_id = osutils.safe_revision_id(rev_id)
             rev = self.get_revision(rev_id, transaction)
             result_graph[rev_id] = rev.parent_ids
         # remove ghosts
@@ -100,7 +109,7 @@
             xml_file.close()
             assert r.revision_id == revision_id
             revisions.append(r)
-        return revisions 
+        return revisions
 
     def _get_revision_xml_file(self, revision_id):
         try:
@@ -119,7 +128,7 @@
         """True if the store contains revision_id."""
         return (revision_id is None
                 or self.text_store.has_id(revision_id))
- 
+
     def _has_signature(self, revision_id, transaction):
         """See RevisionStore._has_signature()."""
         return self.text_store.has_id(revision_id, suffix='sig')

=== modified file 'bzrlib/tests/repository_implementations/test_commit_builder.py'
--- bzrlib/tests/repository_implementations/test_commit_builder.py	2006-11-28 01:56:31 +0000
+++ bzrlib/tests/repository_implementations/test_commit_builder.py	2007-02-10 02:48:43 +0000
@@ -56,7 +56,7 @@
         tree = self.make_branch_and_tree(".")
         # use a unicode revision id to test more corner cases.
         # The repository layer is meant to handle this.
-        revision_id = u'\xc8abc'
+        revision_id = u'\xc8abc'.encode('utf8')
         try:
             try:
                 builder = tree.branch.get_commit_builder([],

=== modified file 'bzrlib/tests/test_knit.py'
--- bzrlib/tests/test_knit.py	2006-12-21 20:07:34 +0000
+++ bzrlib/tests/test_knit.py	2007-02-10 02:48:43 +0000
@@ -156,23 +156,27 @@
             transport.calls.pop(0))
 
     def test_read_utf8_version_id(self):
+        unicode_revision_id = u"version-\N{CYRILLIC CAPITAL LETTER A}"
+        utf8_revision_id = unicode_revision_id.encode('utf-8')
         transport = MockTransport([
             _KnitIndex.HEADER,
-            u"version-\N{CYRILLIC CAPITAL LETTER A}"
-                u" option 0 1 :".encode("utf-8")
+            '%s option 0 1 :' % (utf8_revision_id,)
             ])
         index = _KnitIndex(transport, "filename", "r")
-        self.assertTrue(
-            index.has_version(u"version-\N{CYRILLIC CAPITAL LETTER A}"))
+        # _KnitIndex is a private class, and deals in utf8 revision_ids, not
+        # Unicode revision_ids.
+        self.assertTrue(index.has_version(utf8_revision_id))
+        self.assertFalse(index.has_version(unicode_revision_id))
 
     def test_read_utf8_parents(self):
+        unicode_revision_id = u"version-\N{CYRILLIC CAPITAL LETTER A}"
+        utf8_revision_id = unicode_revision_id.encode('utf-8')
         transport = MockTransport([
             _KnitIndex.HEADER,
-            u"version option 0 1"
-                u" .version-\N{CYRILLIC CAPITAL LETTER A} :".encode("utf-8")
+            "version option 0 1 .%s :" % (utf8_revision_id,)
             ])
         index = _KnitIndex(transport, "filename", "r")
-        self.assertEqual([u"version-\N{CYRILLIC CAPITAL LETTER A}"],
+        self.assertEqual([utf8_revision_id],
             index.get_parents_with_ghosts("version"))
 
     def test_read_ignore_corrupted_lines(self):
@@ -184,7 +188,7 @@
             ])
         index = _KnitIndex(transport, "filename", "r")
         self.assertEqual(1, index.num_versions())
-        self.assertTrue(index.has_version(u"version"))
+        self.assertTrue(index.has_version("version"))
 
     def test_read_corrupted_header(self):
         transport = MockTransport(['not a bzr knit index header\n'])
@@ -201,11 +205,11 @@
             ])
         index = _KnitIndex(transport, "filename", "r")
         self.assertEqual(2, index.num_versions())
-        self.assertEqual(1, index.lookup(u"version"))
-        self.assertEqual((3, 4), index.get_position(u"version"))
-        self.assertEqual(["options3"], index.get_options(u"version"))
-        self.assertEqual([u"parent", u"other"],
-            index.get_parents_with_ghosts(u"version"))
+        self.assertEqual(1, index.lookup("version"))
+        self.assertEqual((3, 4), index.get_position("version"))
+        self.assertEqual(["options3"], index.get_options("version"))
+        self.assertEqual(["parent", "other"],
+            index.get_parents_with_ghosts("version"))
 
     def test_read_compressed_parents(self):
         transport = MockTransport([
@@ -215,32 +219,32 @@
             "c option 0 1 1 0 :",
             ])
         index = _KnitIndex(transport, "filename", "r")
-        self.assertEqual([u"a"], index.get_parents(u"b"))
-        self.assertEqual([u"b", u"a"], index.get_parents(u"c"))
+        self.assertEqual(["a"], index.get_parents("b"))
+        self.assertEqual(["b", "a"], index.get_parents("c"))
 
     def test_write_utf8_version_id(self):
+        unicode_revision_id = u"version-\N{CYRILLIC CAPITAL LETTER A}"
+        utf8_revision_id = unicode_revision_id.encode('utf-8')
         transport = MockTransport([
             _KnitIndex.HEADER
             ])
         index = _KnitIndex(transport, "filename", "r")
-        index.add_version(u"version-\N{CYRILLIC CAPITAL LETTER A}",
-            ["option"], 0, 1, [])
+        index.add_version(utf8_revision_id, ["option"], 0, 1, [])
         self.assertEqual(("append_bytes", ("filename",
-            u"\nversion-\N{CYRILLIC CAPITAL LETTER A}"
-                u" option 0 1  :".encode("utf-8")),
+            "\n%s option 0 1  :" % (utf8_revision_id,)),
             {}),
             transport.calls.pop(0))
 
     def test_write_utf8_parents(self):
+        unicode_revision_id = u"version-\N{CYRILLIC CAPITAL LETTER A}"
+        utf8_revision_id = unicode_revision_id.encode('utf-8')
         transport = MockTransport([
             _KnitIndex.HEADER
             ])
         index = _KnitIndex(transport, "filename", "r")
-        index.add_version(u"version", ["option"], 0, 1,
-            [u"version-\N{CYRILLIC CAPITAL LETTER A}"])
+        index.add_version("version", ["option"], 0, 1, [utf8_revision_id])
         self.assertEqual(("append_bytes", ("filename",
-            u"\nversion option 0 1"
-                u" .version-\N{CYRILLIC CAPITAL LETTER A} :".encode("utf-8")),
+            "\nversion option 0 1 .%s :" % (utf8_revision_id,)),
             {}),
             transport.calls.pop(0))
 
@@ -249,11 +253,11 @@
         index = _KnitIndex(transport, "filename", "w", create=True)
         self.assertEqual([], index.get_graph())
 
-        index.add_version(u"a", ["option"], 0, 1, [u"b"])
-        self.assertEqual([(u"a", [u"b"])], index.get_graph())
+        index.add_version("a", ["option"], 0, 1, ["b"])
+        self.assertEqual([("a", ["b"])], index.get_graph())
 
-        index.add_version(u"c", ["option"], 0, 1, [u"d"])
-        self.assertEqual([(u"a", [u"b"]), (u"c", [u"d"])],
+        index.add_version("c", ["option"], 0, 1, ["d"])
+        self.assertEqual([("a", ["b"]), ("c", ["d"])],
             sorted(index.get_graph()))
 
     def test_get_ancestry(self):
@@ -267,14 +271,14 @@
         index = _KnitIndex(transport, "filename", "r")
 
         self.assertEqual([], index.get_ancestry([]))
-        self.assertEqual([u"a"], index.get_ancestry([u"a"]))
-        self.assertEqual([u"a", u"b"], index.get_ancestry([u"b"]))
-        self.assertEqual([u"a", u"b", u"c"], index.get_ancestry([u"c"]))
-        self.assertEqual([u"a", u"b", u"c", u"d"], index.get_ancestry([u"d"]))
-        self.assertEqual([u"a", u"b"], index.get_ancestry([u"a", u"b"]))
-        self.assertEqual([u"a", u"b", u"c"], index.get_ancestry([u"a", u"c"]))
+        self.assertEqual(["a"], index.get_ancestry(["a"]))
+        self.assertEqual(["a", "b"], index.get_ancestry(["b"]))
+        self.assertEqual(["a", "b", "c"], index.get_ancestry(["c"]))
+        self.assertEqual(["a", "b", "c", "d"], index.get_ancestry(["d"]))
+        self.assertEqual(["a", "b"], index.get_ancestry(["a", "b"]))
+        self.assertEqual(["a", "b", "c"], index.get_ancestry(["a", "c"]))
 
-        self.assertRaises(RevisionNotPresent, index.get_ancestry, [u"e"])
+        self.assertRaises(RevisionNotPresent, index.get_ancestry, ["e"])
 
     def test_get_ancestry_with_ghosts(self):
         transport = MockTransport([
@@ -287,23 +291,23 @@
         index = _KnitIndex(transport, "filename", "r")
 
         self.assertEqual([], index.get_ancestry_with_ghosts([]))
-        self.assertEqual([u"a"], index.get_ancestry_with_ghosts([u"a"]))
-        self.assertEqual([u"a", u"e", u"b"],
-            index.get_ancestry_with_ghosts([u"b"]))
-        self.assertEqual([u"a", u"g", u"f", u"c"],
-            index.get_ancestry_with_ghosts([u"c"]))
-        self.assertEqual([u"a", u"g", u"f", u"c", u"k", u"j", u"h", u"d"],
-            index.get_ancestry_with_ghosts([u"d"]))
-        self.assertEqual([u"a", u"e", u"b"],
-            index.get_ancestry_with_ghosts([u"a", u"b"]))
-        self.assertEqual([u"a", u"g", u"f", u"c"],
-            index.get_ancestry_with_ghosts([u"a", u"c"]))
+        self.assertEqual(["a"], index.get_ancestry_with_ghosts(["a"]))
+        self.assertEqual(["a", "e", "b"],
+            index.get_ancestry_with_ghosts(["b"]))
+        self.assertEqual(["a", "g", "f", "c"],
+            index.get_ancestry_with_ghosts(["c"]))
+        self.assertEqual(["a", "g", "f", "c", "k", "j", "h", "d"],
+            index.get_ancestry_with_ghosts(["d"]))
+        self.assertEqual(["a", "e", "b"],
+            index.get_ancestry_with_ghosts(["a", "b"]))
+        self.assertEqual(["a", "g", "f", "c"],
+            index.get_ancestry_with_ghosts(["a", "c"]))
         self.assertEqual(
-            [u"a", u"g", u"f", u"c", u"e", u"b", u"k", u"j", u"h", u"d"],
-            index.get_ancestry_with_ghosts([u"b", u"d"]))
+            ["a", "g", "f", "c", "e", "b", "k", "j", "h", "d"],
+            index.get_ancestry_with_ghosts(["b", "d"]))
 
         self.assertRaises(RevisionNotPresent,
-            index.get_ancestry_with_ghosts, [u"e"])
+            index.get_ancestry_with_ghosts, ["e"])
 
     def test_num_versions(self):
         transport = MockTransport([
@@ -314,15 +318,15 @@
         self.assertEqual(0, index.num_versions())
         self.assertEqual(0, len(index))
 
-        index.add_version(u"a", ["option"], 0, 1, [])
-        self.assertEqual(1, index.num_versions())
-        self.assertEqual(1, len(index))
-
-        index.add_version(u"a", ["option2"], 1, 2, [])
-        self.assertEqual(1, index.num_versions())
-        self.assertEqual(1, len(index))
-
-        index.add_version(u"b", ["option"], 0, 1, [])
+        index.add_version("a", ["option"], 0, 1, [])
+        self.assertEqual(1, index.num_versions())
+        self.assertEqual(1, len(index))
+
+        index.add_version("a", ["option2"], 1, 2, [])
+        self.assertEqual(1, index.num_versions())
+        self.assertEqual(1, len(index))
+
+        index.add_version("b", ["option"], 0, 1, [])
         self.assertEqual(2, index.num_versions())
         self.assertEqual(2, len(index))
 
@@ -334,14 +338,14 @@
 
         self.assertEqual([], index.get_versions())
 
-        index.add_version(u"a", ["option"], 0, 1, [])
-        self.assertEqual([u"a"], index.get_versions())
-
-        index.add_version(u"a", ["option"], 0, 1, [])
-        self.assertEqual([u"a"], index.get_versions())
-
-        index.add_version(u"b", ["option"], 0, 1, [])
-        self.assertEqual([u"a", u"b"], index.get_versions())
+        index.add_version("a", ["option"], 0, 1, [])
+        self.assertEqual(["a"], index.get_versions())
+
+        index.add_version("a", ["option"], 0, 1, [])
+        self.assertEqual(["a"], index.get_versions())
+
+        index.add_version("b", ["option"], 0, 1, [])
+        self.assertEqual(["a", "b"], index.get_versions())
 
     def test_idx_to_name(self):
         transport = MockTransport([
@@ -351,10 +355,10 @@
             ])
         index = _KnitIndex(transport, "filename", "r")
 
-        self.assertEqual(u"a", index.idx_to_name(0))
-        self.assertEqual(u"b", index.idx_to_name(1))
-        self.assertEqual(u"b", index.idx_to_name(-1))
-        self.assertEqual(u"a", index.idx_to_name(-2))
+        self.assertEqual("a", index.idx_to_name(0))
+        self.assertEqual("b", index.idx_to_name(1))
+        self.assertEqual("b", index.idx_to_name(-1))
+        self.assertEqual("a", index.idx_to_name(-2))
 
     def test_lookup(self):
         transport = MockTransport([
@@ -364,8 +368,8 @@
             ])
         index = _KnitIndex(transport, "filename", "r")
 
-        self.assertEqual(0, index.lookup(u"a"))
-        self.assertEqual(1, index.lookup(u"b"))
+        self.assertEqual(0, index.lookup("a"))
+        self.assertEqual(1, index.lookup("b"))
 
     def test_add_version(self):
         transport = MockTransport([
@@ -373,35 +377,35 @@
             ])
         index = _KnitIndex(transport, "filename", "r")
 
-        index.add_version(u"a", ["option"], 0, 1, [u"b"])
+        index.add_version("a", ["option"], 0, 1, ["b"])
         self.assertEqual(("append_bytes",
             ("filename", "\na option 0 1 .b :"),
             {}), transport.calls.pop(0))
-        self.assertTrue(index.has_version(u"a"))
+        self.assertTrue(index.has_version("a"))
         self.assertEqual(1, index.num_versions())
-        self.assertEqual((0, 1), index.get_position(u"a"))
-        self.assertEqual(["option"], index.get_options(u"a"))
-        self.assertEqual([u"b"], index.get_parents_with_ghosts(u"a"))
+        self.assertEqual((0, 1), index.get_position("a"))
+        self.assertEqual(["option"], index.get_options("a"))
+        self.assertEqual(["b"], index.get_parents_with_ghosts("a"))
 
-        index.add_version(u"a", ["opt"], 1, 2, [u"c"])
+        index.add_version("a", ["opt"], 1, 2, ["c"])
         self.assertEqual(("append_bytes",
             ("filename", "\na opt 1 2 .c :"),
             {}), transport.calls.pop(0))
-        self.assertTrue(index.has_version(u"a"))
+        self.assertTrue(index.has_version("a"))
         self.assertEqual(1, index.num_versions())
-        self.assertEqual((1, 2), index.get_position(u"a"))
-        self.assertEqual(["opt"], index.get_options(u"a"))
-        self.assertEqual([u"c"], index.get_parents_with_ghosts(u"a"))
+        self.assertEqual((1, 2), index.get_position("a"))
+        self.assertEqual(["opt"], index.get_options("a"))
+        self.assertEqual(["c"], index.get_parents_with_ghosts("a"))
 
-        index.add_version(u"b", ["option"], 2, 3, [u"a"])
+        index.add_version("b", ["option"], 2, 3, ["a"])
         self.assertEqual(("append_bytes",
             ("filename", "\nb option 2 3 0 :"),
             {}), transport.calls.pop(0))
-        self.assertTrue(index.has_version(u"b"))
+        self.assertTrue(index.has_version("b"))
         self.assertEqual(2, index.num_versions())
-        self.assertEqual((2, 3), index.get_position(u"b"))
-        self.assertEqual(["option"], index.get_options(u"b"))
-        self.assertEqual([u"a"], index.get_parents_with_ghosts(u"b"))
+        self.assertEqual((2, 3), index.get_position("b"))
+        self.assertEqual(["option"], index.get_options("b"))
+        self.assertEqual(["a"], index.get_parents_with_ghosts("b"))
 
     def test_add_versions(self):
         transport = MockTransport([
@@ -410,24 +414,24 @@
         index = _KnitIndex(transport, "filename", "r")
 
         index.add_versions([
-            (u"a", ["option"], 0, 1, [u"b"]),
-            (u"a", ["opt"], 1, 2, [u"c"]),
-            (u"b", ["option"], 2, 3, [u"a"])
+            ("a", ["option"], 0, 1, ["b"]),
+            ("a", ["opt"], 1, 2, ["c"]),
+            ("b", ["option"], 2, 3, ["a"])
             ])
         self.assertEqual(("append_bytes", ("filename",
             "\na option 0 1 .b :"
             "\na opt 1 2 .c :"
             "\nb option 2 3 0 :"
             ), {}), transport.calls.pop(0))
-        self.assertTrue(index.has_version(u"a"))
-        self.assertTrue(index.has_version(u"b"))
+        self.assertTrue(index.has_version("a"))
+        self.assertTrue(index.has_version("b"))
         self.assertEqual(2, index.num_versions())
-        self.assertEqual((1, 2), index.get_position(u"a"))
-        self.assertEqual((2, 3), index.get_position(u"b"))
-        self.assertEqual(["opt"], index.get_options(u"a"))
-        self.assertEqual(["option"], index.get_options(u"b"))
-        self.assertEqual([u"c"], index.get_parents_with_ghosts(u"a"))
-        self.assertEqual([u"a"], index.get_parents_with_ghosts(u"b"))
+        self.assertEqual((1, 2), index.get_position("a"))
+        self.assertEqual((2, 3), index.get_position("b"))
+        self.assertEqual(["opt"], index.get_options("a"))
+        self.assertEqual(["option"], index.get_options("b"))
+        self.assertEqual(["c"], index.get_parents_with_ghosts("a"))
+        self.assertEqual(["a"], index.get_parents_with_ghosts("b"))
 
     def test_delay_create_and_add_versions(self):
         transport = MockTransport()
@@ -438,9 +442,9 @@
         self.assertEqual([], transport.calls)
 
         index.add_versions([
-            (u"a", ["option"], 0, 1, [u"b"]),
-            (u"a", ["opt"], 1, 2, [u"c"]),
-            (u"b", ["option"], 2, 3, [u"a"])
+            ("a", ["option"], 0, 1, ["b"]),
+            ("a", ["opt"], 1, 2, ["c"]),
+            ("b", ["option"], 2, 3, ["a"])
             ])
         name, (filename, f), kwargs = transport.calls.pop(0)
         self.assertEqual("put_file_non_atomic", name)
@@ -462,8 +466,8 @@
             ])
         index = _KnitIndex(transport, "filename", "r")
 
-        self.assertTrue(index.has_version(u"a"))
-        self.assertFalse(index.has_version(u"b"))
+        self.assertTrue(index.has_version("a"))
+        self.assertFalse(index.has_version("b"))
 
     def test_get_position(self):
         transport = MockTransport([
@@ -473,8 +477,8 @@
             ])
         index = _KnitIndex(transport, "filename", "r")
 
-        self.assertEqual((0, 1), index.get_position(u"a"))
-        self.assertEqual((1, 2), index.get_position(u"b"))
+        self.assertEqual((0, 1), index.get_position("a"))
+        self.assertEqual((1, 2), index.get_position("b"))
 
     def test_get_method(self):
         transport = MockTransport([
@@ -485,9 +489,9 @@
             ])
         index = _KnitIndex(transport, "filename", "r")
 
-        self.assertEqual("fulltext", index.get_method(u"a"))
-        self.assertEqual("line-delta", index.get_method(u"b"))
-        self.assertRaises(errors.KnitIndexUnknownMethod, index.get_method, u"c")
+        self.assertEqual("fulltext", index.get_method("a"))
+        self.assertEqual("line-delta", index.get_method("b"))
+        self.assertRaises(errors.KnitIndexUnknownMethod, index.get_method, "c")
 
     def test_get_options(self):
         transport = MockTransport([
@@ -497,8 +501,8 @@
             ])
         index = _KnitIndex(transport, "filename", "r")
 
-        self.assertEqual(["opt1"], index.get_options(u"a"))
-        self.assertEqual(["opt2", "opt3"], index.get_options(u"b"))
+        self.assertEqual(["opt1"], index.get_options("a"))
+        self.assertEqual(["opt2", "opt3"], index.get_options("b"))
 
     def test_get_parents(self):
         transport = MockTransport([
@@ -509,9 +513,9 @@
             ])
         index = _KnitIndex(transport, "filename", "r")
 
-        self.assertEqual([], index.get_parents(u"a"))
-        self.assertEqual([u"a", u"c"], index.get_parents(u"b"))
-        self.assertEqual([u"b", u"a"], index.get_parents(u"c"))
+        self.assertEqual([], index.get_parents("a"))
+        self.assertEqual(["a", "c"], index.get_parents("b"))
+        self.assertEqual(["b", "a"], index.get_parents("c"))
 
     def test_get_parents_with_ghosts(self):
         transport = MockTransport([
@@ -522,10 +526,10 @@
             ])
         index = _KnitIndex(transport, "filename", "r")
 
-        self.assertEqual([], index.get_parents_with_ghosts(u"a"))
-        self.assertEqual([u"a", u"c"], index.get_parents_with_ghosts(u"b"))
-        self.assertEqual([u"b", u"a", u"e"],
-            index.get_parents_with_ghosts(u"c"))
+        self.assertEqual([], index.get_parents_with_ghosts("a"))
+        self.assertEqual(["a", "c"], index.get_parents_with_ghosts("b"))
+        self.assertEqual(["b", "a", "e"],
+            index.get_parents_with_ghosts("c"))
 
     def test_check_versions_present(self):
         transport = MockTransport([
@@ -538,11 +542,11 @@
         check = index.check_versions_present
 
         check([])
-        check([u"a"])
-        check([u"b"])
-        check([u"a", u"b"])
-        self.assertRaises(RevisionNotPresent, check, [u"c"])
-        self.assertRaises(RevisionNotPresent, check, [u"a", u"b", u"c"])
+        check(["a"])
+        check(["b"])
+        check(["a", "b"])
+        self.assertRaises(RevisionNotPresent, check, ["c"])
+        self.assertRaises(RevisionNotPresent, check, ["a", "b", "c"])
 
 
 class KnitTests(TestCaseWithTransport):

=== modified file 'bzrlib/tests/test_versionedfile.py'
--- bzrlib/tests/test_versionedfile.py	2007-01-11 17:20:25 +0000
+++ bzrlib/tests/test_versionedfile.py	2007-02-10 02:48:43 +0000
@@ -213,36 +213,36 @@
         self.assertEqual(expected_delta, deltas['noeol'])
         # smoke tests for eol support - two noeol in a row same content
         expected_deltas = (('noeol', '3ad7ee82dbd8f29ecba073f96e43e414b3f70a4d', True, 
-                          [(0, 1, 2, [(u'noeolsecond', 'line\n'), (u'noeolsecond', 'line\n')])]),
+                          [(0, 1, 2, [('noeolsecond', 'line\n'), ('noeolsecond', 'line\n')])]),
                           ('noeol', '3ad7ee82dbd8f29ecba073f96e43e414b3f70a4d', True, 
                            [(0, 0, 1, [('noeolsecond', 'line\n')]), (1, 1, 0, [])]))
         self.assertEqual(['line\n', 'line'], f.get_lines('noeolsecond'))
         self.assertTrue(deltas['noeolsecond'] in expected_deltas)
         # two no-eol in a row, different content
         expected_delta = ('noeolsecond', '8bb553a84e019ef1149db082d65f3133b195223b', True, 
-                          [(1, 2, 1, [(u'noeolnotshared', 'phone\n')])])
+                          [(1, 2, 1, [('noeolnotshared', 'phone\n')])])
         self.assertEqual(['line\n', 'phone'], f.get_lines('noeolnotshared'))
         self.assertEqual(expected_delta, deltas['noeolnotshared'])
         # eol folling a no-eol with content change
         expected_delta = ('noeol', 'a61f6fb6cfc4596e8d88c34a308d1e724caf8977', False, 
-                          [(0, 1, 1, [(u'eol', 'phone\n')])])
+                          [(0, 1, 1, [('eol', 'phone\n')])])
         self.assertEqual(['phone\n'], f.get_lines('eol'))
         self.assertEqual(expected_delta, deltas['eol'])
         # eol folling a no-eol with content change
         expected_delta = ('noeol', '6bfa09d82ce3e898ad4641ae13dd4fdb9cf0d76b', False, 
-                          [(0, 1, 1, [(u'eolline', 'line\n')])])
+                          [(0, 1, 1, [('eolline', 'line\n')])])
         self.assertEqual(['line\n'], f.get_lines('eolline'))
         self.assertEqual(expected_delta, deltas['eolline'])
         # eol with no parents
         expected_delta = (None, '264f39cab871e4cfd65b3a002f7255888bb5ed97', True, 
-                          [(0, 0, 1, [(u'noeolbase', 'line\n')])])
+                          [(0, 0, 1, [('noeolbase', 'line\n')])])
         self.assertEqual(['line'], f.get_lines('noeolbase'))
         self.assertEqual(expected_delta, deltas['noeolbase'])
         # eol with two parents, in inverse insertion order
         expected_deltas = (('noeolbase', '264f39cab871e4cfd65b3a002f7255888bb5ed97', True,
-                            [(0, 1, 1, [(u'eolbeforefirstparent', 'line\n')])]),
+                            [(0, 1, 1, [('eolbeforefirstparent', 'line\n')])]),
                            ('noeolbase', '264f39cab871e4cfd65b3a002f7255888bb5ed97', True,
-                            [(0, 1, 1, [(u'eolbeforefirstparent', 'line\n')])]))
+                            [(0, 1, 1, [('eolbeforefirstparent', 'line\n')])]))
         self.assertEqual(['line'], f.get_lines('eolbeforefirstparent'))
         #self.assertTrue(deltas['eolbeforefirstparent'] in expected_deltas)
 
@@ -668,8 +668,11 @@
         # add_lines_with_ghosts api.
         vf = self.get_file()
         # add a revision with ghost parents
+        # The preferred form is utf8, but we should translate when needed
+        parent_id_unicode = u'b\xbfse'
+        parent_id_utf8 = parent_id_unicode.encode('utf8')
         try:
-            vf.add_lines_with_ghosts(u'notbxbfse', [u'b\xbfse'], [])
+            vf.add_lines_with_ghosts(u'notbxbfse', [parent_id_unicode], [])
         except NotImplementedError:
             # check the other ghost apis are also not implemented
             self.assertRaises(NotImplementedError, vf.has_ghost, 'foo')
@@ -681,33 +684,37 @@
         # test key graph related apis: getncestry, _graph, get_parents
         # has_version
         # - these are ghost unaware and must not be reflect ghosts
-        self.assertEqual([u'notbxbfse'], vf.get_ancestry(u'notbxbfse'))
-        self.assertEqual([], vf.get_parents(u'notbxbfse'))
-        self.assertEqual({u'notbxbfse':[]}, vf.get_graph())
-        self.assertFalse(vf.has_version(u'b\xbfse'))
+        self.assertEqual(['notbxbfse'], vf.get_ancestry('notbxbfse'))
+        self.assertEqual([], vf.get_parents('notbxbfse'))
+        self.assertEqual({'notbxbfse':[]}, vf.get_graph())
+        self.assertFalse(vf.has_version(parent_id_unicode))
+        self.assertFalse(vf.has_version(parent_id_utf8))
         # we have _with_ghost apis to give us ghost information.
-        self.assertEqual([u'b\xbfse', u'notbxbfse'], vf.get_ancestry_with_ghosts([u'notbxbfse']))
-        self.assertEqual([u'b\xbfse'], vf.get_parents_with_ghosts(u'notbxbfse'))
-        self.assertEqual({u'notbxbfse':[u'b\xbfse']}, vf.get_graph_with_ghosts())
-        self.assertTrue(vf.has_ghost(u'b\xbfse'))
+        self.assertEqual([parent_id_utf8, 'notbxbfse'], vf.get_ancestry_with_ghosts(['notbxbfse']))
+        self.assertEqual([parent_id_utf8], vf.get_parents_with_ghosts('notbxbfse'))
+        self.assertEqual({'notbxbfse':[parent_id_utf8]}, vf.get_graph_with_ghosts())
+        self.assertTrue(vf.has_ghost(parent_id_unicode))
+        self.assertTrue(vf.has_ghost(parent_id_utf8))
         # if we add something that is a ghost of another, it should correct the
         # results of the prior apis
-        vf.add_lines(u'b\xbfse', [], [])
-        self.assertEqual([u'b\xbfse', u'notbxbfse'], vf.get_ancestry([u'notbxbfse']))
-        self.assertEqual([u'b\xbfse'], vf.get_parents(u'notbxbfse'))
-        self.assertEqual({u'b\xbfse':[],
-                          u'notbxbfse':[u'b\xbfse'],
+        vf.add_lines(parent_id_unicode, [], [])
+        self.assertEqual([parent_id_utf8, 'notbxbfse'], vf.get_ancestry(['notbxbfse']))
+        self.assertEqual([parent_id_utf8], vf.get_parents('notbxbfse'))
+        self.assertEqual({parent_id_utf8:[],
+                          'notbxbfse':[parent_id_utf8],
                           },
                          vf.get_graph())
-        self.assertTrue(vf.has_version(u'b\xbfse'))
+        self.assertTrue(vf.has_version(parent_id_unicode))
+        self.assertTrue(vf.has_version(parent_id_utf8))
         # we have _with_ghost apis to give us ghost information.
-        self.assertEqual([u'b\xbfse', u'notbxbfse'], vf.get_ancestry_with_ghosts([u'notbxbfse']))
-        self.assertEqual([u'b\xbfse'], vf.get_parents_with_ghosts(u'notbxbfse'))
-        self.assertEqual({u'b\xbfse':[],
-                          u'notbxbfse':[u'b\xbfse'],
+        self.assertEqual([parent_id_utf8, 'notbxbfse'], vf.get_ancestry_with_ghosts(['notbxbfse']))
+        self.assertEqual([parent_id_utf8], vf.get_parents_with_ghosts('notbxbfse'))
+        self.assertEqual({parent_id_utf8:[],
+                          'notbxbfse':[parent_id_utf8],
                           },
                          vf.get_graph_with_ghosts())
-        self.assertFalse(vf.has_ghost(u'b\xbfse'))
+        self.assertFalse(vf.has_ghost(parent_id_unicode))
+        self.assertFalse(vf.has_ghost(parent_id_utf8))
 
     def test_add_lines_with_ghosts_after_normal_revs(self):
         # some versioned file formats allow lines to be added with parent

=== modified file 'bzrlib/versionedfile.py'
--- bzrlib/versionedfile.py	2007-01-17 15:37:08 +0000
+++ bzrlib/versionedfile.py	2007-02-10 02:48:43 +0000
@@ -26,6 +26,7 @@
 
 from bzrlib import (
     errors,
+    osutils,
     tsort,
     revision,
     ui,
@@ -96,6 +97,8 @@
         :param sha1: The sha1 of the full text.
         :param delta: The delta instructions. See get_delta for details.
         """
+        version_id = osutils.safe_revision_id(version_id)
+        parents = [osutils.safe_revision_id(v) for v in parents]
         self._check_write_ok()
         if self.has_version(version_id):
             raise errors.RevisionAlreadyPresent(version_id, self)
@@ -138,6 +141,8 @@
                  provided back to future add_lines calls in the parent_texts
                  dictionary.
         """
+        version_id = osutils.safe_revision_id(version_id)
+        parents = [osutils.safe_revision_id(v) for v in parents]
         self._check_write_ok()
         return self._add_lines(version_id, parents, lines, parent_texts)
 
@@ -151,6 +156,8 @@
         
         This takes the same parameters as add_lines.
         """
+        version_id = osutils.safe_revision_id(version_id)
+        parents = [osutils.safe_revision_id(v) for v in parents]
         self._check_write_ok()
         return self._add_lines_with_ghosts(version_id, parents, lines,
                                            parent_texts)
@@ -204,6 +211,8 @@
 
         Must raise RevisionAlreadyPresent if the new version is
         already present in file history."""
+        new_version_id = osutils.safe_revision_id(new_version_id)
+        old_version_id = osutils.safe_revision_id(old_version_id)
         self._check_write_ok()
         return self._clone_text(new_version_id, old_version_id, parents)
 
@@ -220,7 +229,7 @@
         """
         raise NotImplementedError(self.create_empty)
 
-    def fix_parents(self, version, new_parents):
+    def fix_parents(self, version_id, new_parents):
         """Fix the parents list for version.
         
         This is done by appending a new version to the index
@@ -228,10 +237,12 @@
         the parents list must be a superset of the current
         list.
         """
+        version_id = osutils.safe_revision_id(version_id)
+        new_parents = [osutils.safe_revision_id(p) for p in new_parents]
         self._check_write_ok()
-        return self._fix_parents(version, new_parents)
+        return self._fix_parents(version_id, new_parents)
 
-    def _fix_parents(self, version, new_parents):
+    def _fix_parents(self, version_id, new_parents):
         """Helper for fix_parents."""
         raise NotImplementedError(self.fix_parents)
 
@@ -243,7 +254,7 @@
         """
         raise NotImplementedError(self.get_delta)
 
-    def get_deltas(self, versions):
+    def get_deltas(self, version_ids):
         """Get multiple deltas at once for constructing versions.
         
         :return: dict(version_id:(delta_parent, sha1, noeol, delta))
@@ -251,8 +262,8 @@
         version_id is the version_id created by that delta.
         """
         result = {}
-        for version in versions:
-            result[version] = self.get_delta(version)
+        for version_id in version_ids:
+            result[version_id] = self.get_delta(version_id)
         return result
 
     def get_sha1(self, version_id):
@@ -325,7 +336,7 @@
             for version in self.versions():
                 result[version] = self.get_parents(version)
         else:
-            pending = set(version_ids)
+            pending = set(osutils.safe_revision_id(v) for v in version_ids)
             while pending:
                 version = pending.pop()
                 if version in result:
@@ -657,6 +668,7 @@
             # None cannot be in source.versions
             return set(self.source.versions())
         else:
+            version_ids = [osutils.safe_revision_id(v) for v in version_ids]
             if ignore_missing:
                 return set(self.source.versions()).intersection(set(version_ids))
             else:

=== modified file 'bzrlib/xml6.py'
--- bzrlib/xml6.py	2006-10-05 05:37:25 +0000
+++ bzrlib/xml6.py	2007-02-10 02:48:43 +0000
@@ -42,7 +42,7 @@
                                                    % format)
         revision_id = elt.get('revision_id')
         if revision_id is not None:
-            revision_id = cache_utf8.get_cached_unicode(revision_id)
+            revision_id = cache_utf8.encode(revision_id)
         inv = inventory.Inventory(root_id=None, revision_id=revision_id)
         for e in elt:
             ie = self._unpack_entry(e, none_parents=True)

